@@ -2,7 +2,6 @@
 #
 # Unit test cases for buku
 #
-import logging
 import math
 import os
 import re
@@ -12,24 +11,17 @@ import sys
 import unittest
 import urllib
 import zipfile
-
-# fmt: off
 from tempfile import NamedTemporaryFile, TemporaryDirectory
 from unittest import mock
-from genericpath import exists
-# fmt: on
 
 import pytest
-import vcr
 import yaml
+from genericpath import exists
 from hypothesis import example, given, settings
 from hypothesis import strategies as st
 
 from buku import BukuDb, parse_tags, prompt
 
-logging.basicConfig()  # you need to initialize logging, otherwise you will not see anything from vcrpy
-vcr_log = logging.getLogger("vcr")
-vcr_log.setLevel(logging.INFO)
 
 def get_temp_dir_path():
     with TemporaryDirectory(prefix="bukutest_") as dir_obj:
@@ -180,9 +172,9 @@ class TestBukuDb(unittest.TestCase):
             idx_from_db = self.bdb.get_rec_id(bookmark[0])
             self.assertEqual(idx + 1, idx_from_db)
 
-        # asserting -1 is returned for nonexistent url
+        # asserting None is returned for nonexistent url
         idx_from_db = self.bdb.get_rec_id("http://nonexistent.url")
-        self.assertEqual(-1, idx_from_db)
+        self.assertIsNone(idx_from_db)
 
     def test_add_rec(self):
         for bookmark in self.bookmarks:
@@ -380,9 +372,7 @@ class TestBukuDb(unittest.TestCase):
                 expected[0] += tuple([0])
                 self.assertEqual(results, expected)
 
-    @vcr.use_cassette(
-        "tests/vcr_cassettes/test_search_by_multiple_tags_search_any.yaml"
-    )
+    @pytest.mark.vcr("tests/vcr_cassettes/test_search_by_multiple_tags_search_any.yaml")
     def test_search_by_multiple_tags_search_any(self):
         # adding bookmarks
         for bookmark in self.bookmarks:
@@ -432,9 +422,7 @@ class TestBukuDb(unittest.TestCase):
             ]
             self.assertEqual(results, expected)
 
-    @vcr.use_cassette(
-        "tests/vcr_cassettes/test_search_by_multiple_tags_search_all.yaml"
-    )
+    @pytest.mark.vcr("tests/vcr_cassettes/test_search_by_multiple_tags_search_all.yaml")
     def test_search_by_multiple_tags_search_all(self):
         # adding bookmarks
         for bookmark in self.bookmarks:
@@ -564,9 +552,7 @@ class TestBukuDb(unittest.TestCase):
             ]
             self.assertEqual(results, expected)
 
-    @vcr.use_cassette(
-        "tests/vcr_cassettes/test_search_by_tags_enforces_space_seprations_exclusion.yaml"
-    )
+    @pytest.mark.vcr("tests/vcr_cassettes/test_search_by_tags_enforces_space_seprations_exclusion.yaml")
     def test_search_by_tags_enforces_space_seprations_exclusion(self):
 
         bookmark1 = [
@@ -653,7 +639,7 @@ class TestBukuDb(unittest.TestCase):
                 # checking if browse called with expected arguments
                 self.assertEqual(arg_list, expected)
 
-    @vcr.use_cassette("tests/vcr_cassettes/test_search_and_open_all_in_browser.yaml")
+    @pytest.mark.vcr("tests/vcr_cassettes/test_search_and_open_all_in_browser.yaml")
     def test_search_and_open_all_in_browser(self):
         # adding bookmarks
         for bookmark in self.bookmarks:
@@ -1053,11 +1039,11 @@ def test_delete_rec_on_empty_database(setup, index, is_range, low, high):
 @pytest.mark.parametrize(
     "kwargs, exp_res, raise_error",
     [
-        [dict(index="a", low="a", high=1, is_range=True), None, True],
-        [dict(index="a", low="a", high=1, is_range=False), None, True],
-        [dict(index="a", low=1, high="a", is_range=True), None, True],
-        [dict(index="a", is_range=False), None, True],
-        [dict(index="a", is_range=True), None, True],
+        [{"index": 'a', "low": 'a', "high": 1, "is_range": True}, None, True],
+        [{"index": 'a', "low": 'a', "high": 1, "is_range": False}, None, True],
+        [{"index": 'a', "low": 1, "high": 'a', "is_range": True}, None, True],
+        [{"index": 'a', "is_range": False}, None, True],
+        [{"index": 'a', "is_range": True}, None, True],
     ],
 )
 def test_delete_rec_on_non_integer(
@@ -1090,7 +1076,7 @@ def test_add_rec_add_invalid_url(caplog, url):
     """test method."""
     bdb = BukuDb()
     res = bdb.add_rec(url=url)
-    assert res == -1
+    assert res is None
     caplog.records[0].levelname == "ERROR"
     caplog.records[0].getMessage() == "Invalid URL"
 
@@ -1098,34 +1084,34 @@ def test_add_rec_add_invalid_url(caplog, url):
 @pytest.mark.parametrize(
     "kwargs, exp_arg",
     [
-        [{"url": "example.com"}, ("example.com", "Example Domain", ",", "", 0)],
+        [{"url": "example.com"}, ("example.com", "Example Domain", ",", "", False)],
         [
             {"url": "http://example.com"},
-            ("http://example.com", "Example Domain", ",", "", 0),
+            ("http://example.com", "Example Domain", ",", "", False),
         ],
         [
-            {"url": "http://example.com", "immutable": 1},
-            ("http://example.com", "Example Domain", ",", "", 1),
+            {"url": "http://example.com", "immutable": True},
+            ("http://example.com", "Example Domain", ",", "", True),
         ],
         [
             {"url": "http://example.com", "desc": "randomdesc"},
-            ("http://example.com", "Example Domain", ",", "randomdesc", 0),
+            ("http://example.com", "Example Domain", ",", "randomdesc", False),
         ],
         [
             {"url": "http://example.com", "title_in": "randomtitle"},
-            ("http://example.com", "randomtitle", ",", "", 0),
+            ("http://example.com", "randomtitle", ",", "", False),
         ],
         [
             {"url": "http://example.com", "tags_in": "tag1"},
-            ("http://example.com", "Example Domain", ",tag1,", "", 0),
+            ("http://example.com", "Example Domain", ",tag1,", "", False),
         ],
         [
             {"url": "http://example.com", "tags_in": ",tag1"},
-            ("http://example.com", "Example Domain", ",tag1,", "", 0),
+            ("http://example.com", "Example Domain", ",tag1,", "", False),
         ],
         [
             {"url": "http://example.com", "tags_in": ",tag1,"},
-            ("http://example.com", "Example Domain", ",tag1,", "", 0),
+            ("http://example.com", "Example Domain", ",tag1,", "", False),
         ],
     ],
 )
@@ -1133,7 +1119,7 @@ def test_add_rec_exec_arg(kwargs, exp_arg):
     """test func."""
     bdb = BukuDb()
     bdb.cur = mock.Mock()
-    bdb.get_rec_id = mock.Mock(return_value=-1)
+    bdb.get_rec_id = mock.Mock(return_value=None)
     bdb.add_rec(**kwargs)
     assert bdb.cur.execute.call_args[0][1] == exp_arg
 
@@ -1150,9 +1136,9 @@ def test_update_rec_index_0(caplog):
 @pytest.mark.parametrize(
     "kwargs, exp_res",
     [
-        [dict(index=1), False],
-        [dict(index=1, url="url"), False],
-        [dict(index=1, url=""), False],
+        [{"index": 1}, False],
+        [{"index": 1, "url": 'url'}, False],
+        [{"index": 1, "url": ''}, False],
     ],
 )
 def test_update_rec(tmp_path, kwargs, exp_res):
@@ -1219,7 +1205,7 @@ def test_edit_update_rec_with_invalid_input(get_system_editor_retval, index, exp
         assert res == exp_res
 
 
-@vcr.use_cassette("tests/vcr_cassettes/test_browse_by_index.yaml")
+@pytest.mark.vcr("tests/vcr_cassettes/test_browse_by_index.yaml")
 @given(
     low=st.integers(min_value=-2, max_value=3),
     high=st.integers(min_value=-2, max_value=3),
@@ -1422,7 +1408,7 @@ def test_exportdb_to_db():
 @pytest.mark.parametrize(
     "urls, exp_res",
     [
-        [[], -1],
+        [[], None],
         [["http://example.com"], 1],
         [["htttp://example.com", "http://google.com"], 2],
     ],
